function [P,F,states]=markov_word(T,n)
%MARKOV_WORD parses a chunk of text, T, into n character strings.  These
%strings are the states of the Markov chain.  The entries of the transition
%matrix are the probabilities, calculated from T that state j follows state
%i.
%
%
%INPUTS:  T= text, n = state string length
%OUTPUTS:  P=transitions matrix, F=state frequency, states=names of states
num_char=numel(T); %find the number of characters in the string
num_nodes=num_char-(n-1);  %count the number of distinct states
%create a cell array of states
for i=1:num_nodes
    full_state_list{i}=T(i:i+(n-1));
end
%take only unique ones for our list of states
states=cell2mat(unique(full_state_list));
states=reshape(states,n,numel(states)/n)';
%next, we compute the state frequency as well as the transition
%probabilities
P=zeros(size(states,1),size(states,1));
F=zeros(1,size(states,1));
% create a more readable full_state_list
flst=reshape(cell2mat(full_state_list),n,size(cell2mat(full_state_list),2)/n)';
lastind=(size(flst,1)-(n-1)):size(flst,1);
for i=1:size(states,1)
    inds=strmatch(states(i,:),flst);
    F(i)=numel(inds);inds=setdiff(inds, lastind);
    neighbors=flst(inds+repmat(n,size(inds,1),size(inds,2)),:);
    for j=1:size(neighbors,1)
        indsn=strmatch(neighbors(j,:),states);
        P(i,indsn)=P(i,indsn)+1;
    end
    P(i,:)=P(i,:)/F(i);
end